/*
 * Copyright 2006-2008 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.osgi.compendium.internal.cm;

import java.util.Map;

import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.support.AbstractBeanFactory;

/**
 * Container-managed update. Locks the instance and performs autowire by name
 * injection.
 * 
 * @author Costin Leau
 */
class ContainerManagedUpdate implements UpdateCallback {

	private final AbstractBeanFactory beanFactory;


	/**
	 * Constructs a new <code>ContainerManagedUpdate</code> instance.
	 * 
	 * @param beanFactory
	 */
	public ContainerManagedUpdate(BeanFactory beanFactory) {
		super();
		this.beanFactory = (beanFactory instanceof AbstractBeanFactory ? (AbstractBeanFactory) beanFactory : null);
	}

	public void update(Object instance, Map properties) {
		synchronized (instance) {
			CMUtils.applyMapOntoInstance(instance, properties, beanFactory);
		}
	}
}